@@ -567,7 +567,7 @@ class comscore_omnicom_database:
         return DataFrameDict, frame
     
     def bayesian_inference_over_sites(self, country = None, domain = None, 
-                                      time_spent = None, start_date = None, end_date = None):
+                                      time_spent = None, start_date = None, end_date = None, saved = False):
         """A function that uses the Bayes theorem to calculate which sites are most likely to be visited by a user who visits our site.
 
         Note:
@@ -682,12 +682,16 @@ class comscore_omnicom_database:
         dataframe_probs_a.reset_index(drop = True, inplace = True)
         
         short_frame = dataframe_probs_a[dataframe_probs_a['bayes %'] > 0.4].reset_index(drop = True)
+
+        if saved:
+            path_file = input('define your personal path to save the file: ')
+            short_frame.to_csv(path_file + 'bayesianinference_sites_prob_{}_{}_{}.csv'.format(domain.replace('.', '-'), start_date, end_date))
         
         return dataframe_probs_a, short_frame
 
     def bayesian_site_predictor(self, country = None, 
                                 domain = None, time_spent = None, 
-                                start_date = None, end_date = None):
+                                start_date = None, end_date = None, saved = False):
             """A function to know which is the next most likely site to visit after a user visits our site.
 
         Note:
@@ -931,4 +935,8 @@ class comscore_omnicom_database:
             
             short_frame_a = dataframe_probs_a[dataframe_probs_a['bayes %'] > 0.4].reset_index(drop = True)
             
+            if saved:
+                path_file = input('define your personal path to save the file: ')
+                short_frame_a.to_csv(path_file + 'bayesianinference_sites_prob_{}_{}_{}.csv'.format(domain.replace('.', '-'), start_date, end_date))
+
             return short_frame_a, dataframe_probs_a
\ No newline at end of file
